pub enum AggregateInputMode {
Raw,
Partial,
}Expand description
Whether an aggregate stage consumes raw input data or intermediate accumulator state from a previous aggregation stage.
See the table on AggregateMode
for how this relates to aggregate modes.
Variants
Raw
The stage consumes raw, unaggregated input data and calls
Accumulator::update_batch.
Partial
The stage consumes intermediate accumulator state from a previous
aggregation stage and calls Accumulator::merge_batch.