AggregateOutputMode

Enum AggregateOutputMode 

pub enum AggregateOutputMode {
    Partial,
    Final,
}
Whether an aggregate stage produces intermediate accumulator state or final output values.

See the table on AggregateMode for how this relates to aggregate modes.

Variants



Partial

The stage produces intermediate accumulator state, serialized via Accumulator::state.



Final

The stage produces final output values via Accumulator::evaluate.