pub struct AggregateExec {
pub input: Arc<dyn ExecutionPlan>,
pub input_schema: SchemaRef,
/* private fields */
}Expand description
Hash aggregate execution plan
Fields
input: Arc<dyn ExecutionPlan>Input plan, could be a partial aggregate or the input to the aggregate
input_schema: SchemaRefInput schema before any aggregation is applied. For partial aggregate this will be the
same as input.schema() but for the final aggregate it will be the same as the input
to the partial aggregate, i.e., partial and final aggregates have same input_schema.
We need the input schema of partial aggregate to be able to deserialize aggregate
expressions from protobuf for final aggregate.
Implementations
Sourceimpl AggregateExec
impl AggregateExec
Sourcepub fn with_new_aggr_exprs(
&self,
aggr_expr: impl Into<Arc<[Arc<AggregateFunctionExpr>]>>,
) -> Self
pub fn with_new_aggr_exprs( &self, aggr_expr: impl Into<Arc<[Arc<AggregateFunctionExpr>]>>, ) -> Self
Function used in OptimizeAggregateOrder optimizer rule,
where we need parts of the new value, others cloned from the old one
Rewrites aggregate exec with new aggregate expressions.
Sourcepub fn with_new_limit_options(
&self,
limit_options: Option<LimitOptions>,
) -> Self
pub fn with_new_limit_options( &self, limit_options: Option<LimitOptions>, ) -> Self
Clone this exec, overriding only the limit hint.
pub fn cache(&self) -> &PlanProperties
Sourcepub fn try_new(
mode: AggregateMode,
group_by: impl Into<Arc<PhysicalGroupBy>>,
aggr_expr: Vec<Arc<AggregateFunctionExpr>>,
filter_expr: Vec<Option<Arc<dyn PhysicalExpr>>>,
input: Arc<dyn ExecutionPlan>,
input_schema: SchemaRef,
) -> Result<Self>
pub fn try_new( mode: AggregateMode, group_by: impl Into<Arc<PhysicalGroupBy>>, aggr_expr: Vec<Arc<AggregateFunctionExpr>>, filter_expr: Vec<Option<Arc<dyn PhysicalExpr>>>, input: Arc<dyn ExecutionPlan>, input_schema: SchemaRef, ) -> Result<Self>
Create a new hash aggregate execution plan
Sourcepub fn mode(&self) -> &AggregateMode
pub fn mode(&self) -> &AggregateMode
Aggregation mode (full, partial)
Sourcepub fn with_limit_options(self, limit_options: Option<LimitOptions>) -> Self
pub fn with_limit_options(self, limit_options: Option<LimitOptions>) -> Self
Set the limit options for this AggExec
Sourcepub fn limit_options(&self) -> Option<LimitOptions>
pub fn limit_options(&self) -> Option<LimitOptions>
Get the limit options (if set)
Sourcepub fn group_expr(&self) -> &PhysicalGroupBy
pub fn group_expr(&self) -> &PhysicalGroupBy
Grouping expressions
Sourcepub fn output_group_expr(&self) -> Vec<Arc<dyn PhysicalExpr>>
pub fn output_group_expr(&self) -> Vec<Arc<dyn PhysicalExpr>>
Grouping expressions as they occur in the output schema
Sourcepub fn aggr_expr(&self) -> &[Arc<AggregateFunctionExpr>]
pub fn aggr_expr(&self) -> &[Arc<AggregateFunctionExpr>]
Aggregate expressions
Sourcepub fn filter_expr(&self) -> &[Option<Arc<dyn PhysicalExpr>>]
pub fn filter_expr(&self) -> &[Option<Arc<dyn PhysicalExpr>>]
FILTER (WHERE clause) expression for each aggregate expression
Sourcepub fn dynamic_filter_expr(&self) -> Option<&Arc<DynamicFilterPhysicalExpr>>
👎Deprecated since 55.0.0: Use ExecutionPlan::dynamic_expressions_produced instead
pub fn dynamic_filter_expr(&self) -> Option<&Arc<DynamicFilterPhysicalExpr>>
Use ExecutionPlan::dynamic_expressions_produced instead
Returns the dynamic filter expression for this aggregate, if set.
Sourcepub fn with_dynamic_filter_expr(
self,
filter: Arc<DynamicFilterPhysicalExpr>,
) -> Result<Self>
pub fn with_dynamic_filter_expr( self, filter: Arc<DynamicFilterPhysicalExpr>, ) -> Result<Self>
Replace the dynamic filter expression. This method errors if the aggregate does not
support dynamic filtering or if the filter expression is incompatible with this
AggregateExec.
Sourcepub fn input(&self) -> &Arc<dyn ExecutionPlan> ⓘ
pub fn input(&self) -> &Arc<dyn ExecutionPlan> ⓘ
Input plan
Sourcepub fn input_schema(&self) -> SchemaRef
pub fn input_schema(&self) -> SchemaRef
Get the input schema before any aggregates are applied
Sourcepub fn get_minmax_desc(&self) -> Option<(FieldRef, bool)>
pub fn get_minmax_desc(&self) -> Option<(FieldRef, bool)>
Finds the DataType and SortDirection for this Aggregate, if there is one
Sourcepub fn is_unordered_unfiltered_group_by_distinct(&self) -> bool
pub fn is_unordered_unfiltered_group_by_distinct(&self) -> bool
true, if this Aggregate has a group-by with no required or explicit ordering, no filtering and no aggregate expressions This method qualifies the use of the LimitedDistinctAggregation rewrite rule on an AggregateExec.
Sourcepub fn compute_properties(
input: &Arc<dyn ExecutionPlan>,
schema: SchemaRef,
group_expr_mapping: &ProjectionMapping,
is_true_no_grouping: bool,
mode: &AggregateMode,
input_order_mode: &InputOrderMode,
aggr_exprs: &[Arc<AggregateFunctionExpr>],
) -> Result<PlanProperties>
pub fn compute_properties( input: &Arc<dyn ExecutionPlan>, schema: SchemaRef, group_expr_mapping: &ProjectionMapping, is_true_no_grouping: bool, mode: &AggregateMode, input_order_mode: &InputOrderMode, aggr_exprs: &[Arc<AggregateFunctionExpr>], ) -> Result<PlanProperties>
This function creates the cache object that stores the plan properties such as schema, equivalence properties, ordering, partitioning, etc.
pub fn input_order_mode(&self) -> &InputOrderMode
Sourceimpl AggregateExec
impl AggregateExec
Sourcepub fn try_from_proto(
node: &PhysicalPlanNode,
ctx: &ExecutionPlanDecodeCtx<'_>,
) -> Result<Arc<dyn ExecutionPlan>>
Available on crate feature proto only.
pub fn try_from_proto( node: &PhysicalPlanNode, ctx: &ExecutionPlanDecodeCtx<'_>, ) -> Result<Arc<dyn ExecutionPlan>>
proto only.Reconstruct an AggregateExec from its protobuf representation.
Grouping expressions are decoded against the child schema. Aggregate arguments, ordering, filters, and the dynamic filter are decoded against the aggregate input schema carried in the protobuf node.