Module buffer

Module buffer 

BufferExec decouples production and consumption on messages by buffering the input in the background up to a certain capacity.

Structs

BufferExec
WARNING: EXPERIMENTAL
MemoryBufferedStream
Decouples production and consumption of messages in a stream with an internal queue, eagerly filling it up to the specified maximum capacity even before any message is requested.

Traits

SizedMessage
Represents anything that occupies a capacity in a MemoryBufferedStream.