pub trait SizedMessage {
// Required method
fn size(&self) -> usize;
}Expand description
Represents anything that occupies a capacity in a MemoryBufferedStream.
pub trait SizedMessage {
// Required method
fn size(&self) -> usize;
}Represents anything that occupies a capacity in a MemoryBufferedStream.