Re-exports
pub use crate::display::DefaultDisplay;pub use crate::display::DisplayAs;pub use crate::display::DisplayFormatType;pub use crate::display::VerboseDisplay;pub use crate::stream::EmptyRecordBatchStream;
Modules
- expressions
- Defines physical expressions that can evaluated at runtime during query execution
- hash_
utils - Functionality used both on logical and physical plans
Macros
- internal_
err - Macro wraps Err(
$ERR) to add backtrace feature
Structs
- Column
Statistics - Statistics for a column within a relation
- Metric
- Something that tracks a value of interest (metric) during execution.
- Plan
Properties - Stores plan properties used in query optimization.
- Replace
Children Options - Options for
ExecutionPlan::replace_children - Statistics
- Statistics for a relation Fields are optional and can be inexact because the sources sometimes provide approximate estimates for performance reasons and the transformations output are not always predictable.
Enums
- Boundedness
- Represents whether a stream of data generated by an operator is bounded (finite) or unbounded (infinite).
- Cardinality
Effect - Indicates the effect an execution plan operator will have on the cardinality of its input stream
- Children
Properties Mode - Indicates whether the plan properties of the new children must be recomputed.
- Columnar
Value - The result of evaluating an expression.
- Distribution
- How data is distributed amongst partitions. See
Partitioningfor more details. - Emission
Type - Represents how an operator emits its output records.
- Evaluation
Type - Represents how an operator’s stream drives
RecordBatchproduction relative to downstream demand. - Input
Order Mode - Specifies how the input to an aggregation or window operator is ordered
relative to their
GROUP BYorPARTITION BYexpressions. - Invariant
Level ExecutionPlanInvariant Level- Partitioning
- Output partitioning supported by
ExecutionPlans. - Scheduling
Type - Represents whether an operator’s
Streamhas been implemented to actively cooperate with the Tokio scheduler or not. Please refer to thecoopmodule for more details.
Traits
- Accumulator
- Tracks an aggregate function’s state.
- AsPhysical
Expr Ref - Allows a type to be treated as a reference to an
Arc<dyn PhysicalExpr>. - Execution
Plan - Represent nodes in the DataFusion Physical Plan.
- Execution
Plan Properties - Extension trait provides an easy API to fetch various properties of
ExecutionPlanobjects based onExecutionPlan::properties. - Physical
Expr PhysicalExprs represent expressions such asA + 1orCAST(c1 AS int).- Record
Batch Stream - Trait for types that stream RecordBatch
- Window
Expr - Common trait for window function implementations
Functions
- apply_
expression_ roots - Applies
fto a shallow sequence of physical expression roots. - check_
default_ invariants - Checks a set of invariants that apply to all ExecutionPlan implementations. Returns an error if the given node does not conform.
- check_
not_ null_ constraints - Checks a
RecordBatchfornot nullconstraints on specified columns. - collect
- Execute the ExecutionPlan and collect the results in memory
- collect_
partitioned - Execute the ExecutionPlan and collect the results in memory
- displayable
- Return a
DisplayableExecutionPlanwrapper around anExecutionPlanwhich can be displayed in various easier to understand ways. - execute_
input_ stream - Executes an input stream and ensures that the resulting stream adheres to
the
not nullconstraints specified in thesink_schema. - execute_
stream - Execute the ExecutionPlan and return a single stream of
RecordBatches. - execute_
stream_ partitioned - Execute the ExecutionPlan and return a vec with one stream per output partition
- get_
plan_ string - Utility function yielding a string representation of the given
ExecutionPlan. - has_
same_ children_ properties - Check if the
planchildren has the same properties as passedchildren. In this case plan can avoid self properties re-computation when its children replace is requested. The size ofchildrenmust be equal to the size ofExecutionPlan::children(). - need_
data_ exchange - Indicate whether a data exchange is needed for the input of
plan. - project_
schema - Applies an optional projection to a
SchemaRef, returning the projected schema - replace_
children_ if_ necessary - Returns a plan with the given children, skipping as much work as possible.
- reset_
plan_ states - Make plan ready to be re-executed returning its clone with state reset for all nodes.
- with_
new_ children_ if_ necessary Deprecated
Type Aliases
- Sendable
Record Batch Stream - Trait for a
StreamofRecordBatches that can be passed between threads