pub enum ChildrenPropertiesMode {
Keep,
Recompute,
}Expand description
Indicates whether the plan properties of the new children must be recomputed.
Part of ReplaceChildrenOptions.
Variants
Keep
The plan properties of the new children are identical to the properties of the existing children, so we can skip recomputation.
Recompute
The plan properties of the new children are different from the properties of the existing children, so we must recompute the properties from scratch.