RecordBatchStream

Trait RecordBatchStream 

pub trait RecordBatchStream: Stream<Item = Result<RecordBatch, DataFusionError>> {
    // Required method
    fn schema(&self) -> Arc<Schema> ;
}
Trait for types that stream RecordBatch

See SendableRecordBatchStream for more details.

Required Methods

fn schema(&self) -> Arc<Schema>

Returns the schema of this RecordBatchStream.

Implementation of this trait should guarantee that all RecordBatch’s returned by this stream should have the same schema as returned from this method.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors