pub struct FilterExec { /* private fields */ }Expand description
FilterExec evaluates a boolean predicate against all input batches to determine which rows to include in its output batches.
Implementations
Sourceimpl FilterExec
impl FilterExec
Sourcepub fn try_new(
predicate: Arc<dyn PhysicalExpr>,
input: Arc<dyn ExecutionPlan>,
) -> Result<Self>
pub fn try_new( predicate: Arc<dyn PhysicalExpr>, input: Arc<dyn ExecutionPlan>, ) -> Result<Self>
Create a FilterExec on an input using the builder pattern
Sourcepub fn batch_size(&self) -> usize
pub fn batch_size(&self) -> usize
Get a batch size
Sourcepub fn with_default_selectivity(
self,
default_selectivity: u8,
) -> Result<Self, DataFusionError>
pub fn with_default_selectivity( self, default_selectivity: u8, ) -> Result<Self, DataFusionError>
Set the default selectivity
Sourcepub fn with_projection(&self, projection: Option<Vec<usize>>) -> Result<Self>
👎Deprecated since 52.0.0: Use FilterExecBuilder::apply_projection instead
pub fn with_projection(&self, projection: Option<Vec<usize>>) -> Result<Self>
Use FilterExecBuilder::apply_projection instead
Return new instance of FilterExec with the given projection.
Deprecated
Use FilterExecBuilder::apply_projection instead
Sourcepub fn with_batch_size(&self, batch_size: usize) -> Result<Self>
pub fn with_batch_size(&self, batch_size: usize) -> Result<Self>
Set the batch size
Sourcepub fn predicate(&self) -> &Arc<dyn PhysicalExpr> ⓘ
pub fn predicate(&self) -> &Arc<dyn PhysicalExpr> ⓘ
The expression to filter on. This expression must evaluate to a boolean value.
Sourcepub fn input(&self) -> &Arc<dyn ExecutionPlan> ⓘ
pub fn input(&self) -> &Arc<dyn ExecutionPlan> ⓘ
The input plan
Sourcepub fn default_selectivity(&self) -> u8
pub fn default_selectivity(&self) -> u8
The default selectivity
Sourcepub fn projection(&self) -> &Option<ProjectionRef>
pub fn projection(&self) -> &Option<ProjectionRef>
Projection
Sourceimpl FilterExec
impl FilterExec
Sourcepub fn try_from_proto(
node: &PhysicalPlanNode,
ctx: &ExecutionPlanDecodeCtx<'_>,
) -> Result<Arc<dyn ExecutionPlan>>
Available on crate feature proto only.
pub fn try_from_proto( node: &PhysicalPlanNode, ctx: &ExecutionPlanDecodeCtx<'_>, ) -> Result<Arc<dyn ExecutionPlan>>
proto only.Reconstruct a FilterExec from its protobuf representation.
The exact inverse of ExecutionPlan::try_to_proto: it takes the whole
PhysicalPlanNode so every plan’s try_from_proto shares one signature.