FilterExecBuilder

Struct FilterExecBuilder 

pub struct FilterExecBuilder { /* private fields */ }
Builder for FilterExec to set optional parameters

Implementations

Source

impl FilterExecBuilder

pub fn new( predicate: Arc<dyn PhysicalExpr>, input: Arc<dyn ExecutionPlan>, ) -> Self

Create a new builder with required parameters (predicate and input)

pub fn with_input(self, input: Arc<dyn ExecutionPlan>) -> Self

Set the input execution plan

pub fn with_predicate(self, predicate: Arc<dyn PhysicalExpr>) -> Self

Set the predicate expression

pub fn apply_projection(self, projection: Option<Vec<usize>>) -> Result<Self>

Set the projection, composing with any existing projection.

If a projection is already set, the new projection indices are mapped through the existing projection. For example, if the current projection is [0, 2, 3] and apply_projection(Some(vec![0, 2])) is called, the resulting projection will be [0, 3] (indices 0 and 2 of [0, 2, 3]).

If no projection is currently set, the new projection is used directly. If None is passed, the projection is cleared.

pub fn apply_projection_by_ref( self, projection: Option<&ProjectionRef>, ) -> Result<Self>

The same as Self::apply_projection but takes projection shared reference.

pub fn with_default_selectivity(self, default_selectivity: u8) -> Self

Set the default selectivity

pub fn with_batch_size(self, batch_size: usize) -> Self

Set the batch size

pub fn with_fetch(self, fetch: Option<usize>) -> Self

Set the fetch limit

pub fn build(self) -> Result<FilterExec>

Build the FilterExec, computing properties once with all configured parameters