SeededRandomState

Struct SeededRandomState 

pub struct SeededRandomState { /* private fields */ }
RandomState wrapper that preserves the seeds used to create it.

This is needed because ahash’s RandomState doesn’t expose its seeds after creation, but we need them for serialization (e.g., protobuf serde).

Implementations

Source

impl SeededRandomState

pub const fn with_seeds(k0: u64, k1: u64, k2: u64, k3: u64) -> Self

Create a new SeededRandomState with the given seeds.

pub fn random_state(&self) -> &RandomState

Get the inner RandomState.

pub fn seeds(&self) -> (u64, u64, u64, u64)

Get the seeds used to create this RandomState.