pub struct ProjectionExpr {
pub expr: Arc<dyn PhysicalExpr>,
pub alias: String,
}Expand description
An expression used by projection operations.
The expression is evaluated and the result is stored in a column
with the name specified by alias.
For example, the SQL expression a + b AS sum_ab would be represented
as a ProjectionExpr where expr is the expression a + b
and alias is the string sum_ab.
See ProjectionExprs for a collection of projection expressions.
Fields
expr: Arc<dyn PhysicalExpr>The expression that will be evaluated.
alias: StringThe name of the output column for use an output schema.
Implementations
Sourceimpl ProjectionExpr
impl ProjectionExpr
Sourcepub fn new(
expr: Arc<dyn PhysicalExpr>,
alias: impl Into<String>,
) -> ProjectionExpr
pub fn new( expr: Arc<dyn PhysicalExpr>, alias: impl Into<String>, ) -> ProjectionExpr
Create a new projection expression
Sourcepub fn new_from_expression(
expr: Arc<dyn PhysicalExpr>,
schema: &Schema,
) -> Result<ProjectionExpr, DataFusionError>
pub fn new_from_expression( expr: Arc<dyn PhysicalExpr>, schema: &Schema, ) -> Result<ProjectionExpr, DataFusionError>
Create a new projection expression from an expression and a schema using the expression’s output field name as alias.