pub struct RecursiveQueryExec { /* private fields */ }Expand description
Recursive query execution plan.
This plan has two components: a base part (the static term) and a dynamic part (the recursive term). The execution will start from the base, and as long as the previous iteration produced at least a single new row (taking care of the distinction) the recursive part will be continuously executed.
Before each execution of the dynamic part, the rows from the previous iteration will be available in a “working table” (not a real table, can be only accessed using a continuance operation).
Note that there won’t be any limit or checks applied to detect an infinite recursion, so it is up to the planner to ensure that it won’t happen.
Implementations
Sourceimpl RecursiveQueryExec
impl RecursiveQueryExec
Sourcepub fn try_new(
name: String,
output_schema: SchemaRef,
static_term: Arc<dyn ExecutionPlan>,
recursive_term: Arc<dyn ExecutionPlan>,
is_distinct: bool,
) -> Result<Self>
pub fn try_new( name: String, output_schema: SchemaRef, static_term: Arc<dyn ExecutionPlan>, recursive_term: Arc<dyn ExecutionPlan>, is_distinct: bool, ) -> Result<Self>
Create a new RecursiveQueryExec
Sourcepub fn static_term(&self) -> &Arc<dyn ExecutionPlan> ⓘ
pub fn static_term(&self) -> &Arc<dyn ExecutionPlan> ⓘ
Ref to static term
Sourcepub fn recursive_term(&self) -> &Arc<dyn ExecutionPlan> ⓘ
pub fn recursive_term(&self) -> &Arc<dyn ExecutionPlan> ⓘ
Ref to recursive term
Sourcepub fn is_distinct(&self) -> bool
pub fn is_distinct(&self) -> bool
is distinct