pub struct StatisticsArgs { /* private fields */ }Expand description
Arguments passed to ExecutionPlan::statistics_from_inputs carrying
external information that operators can use when computing their
statistics.
Implementations
Sourceimpl StatisticsArgs
impl StatisticsArgs
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates new statistics arguments.
By default the partition is set to None (statistics should be computed
for the entire plan).
Sourcepub fn set_partition(&mut self, partition: Option<usize>)
pub fn set_partition(&mut self, partition: Option<usize>)
Set the partition to compute statistics
Nonemeans statistics should be computed for the entire plan.Some(idx)means statistics should be computed for the specified partition index.
Sourcepub fn with_partition(self, partition: Option<usize>) -> Self
pub fn with_partition(self, partition: Option<usize>) -> Self
Builder Style API for Self::set_partition