pub struct BarrierExec { /* private fields */ }Expand description
A Mock ExecutionPlan that does not start producing input until a barrier is called
Implementations
Sourceimpl BarrierExec
impl BarrierExec
Sourcepub fn new(data: Vec<Vec<RecordBatch>>, schema: SchemaRef) -> Self
pub fn new(data: Vec<Vec<RecordBatch>>, schema: SchemaRef) -> Self
Create a new exec with some number of partitions.
pub fn with_log(self, log: bool) -> Self
pub fn without_start_barrier(self) -> Self
pub fn with_finish_barrier(self) -> Self
pub async fn wait_finish(&self)
Sourcepub fn is_finish_barrier_reached(&self) -> bool
pub fn is_finish_barrier_reached(&self) -> bool
Return true if the finish barrier has been reached in all partitions