pub struct BlockingExec { /* private fields */ }Expand description
Execution plan that emits streams that block forever.
This is useful to test shutdown / cancellation behavior of certain execution plans.
Implementations
Sourceimpl BlockingExec
impl BlockingExec
Sourcepub fn new(schema: SchemaRef, n_partitions: usize) -> Self
pub fn new(schema: SchemaRef, n_partitions: usize) -> Self
Create new BlockingExec with a give schema and number of partitions.
Sourcepub fn refs(&self) -> Weak<()>
pub fn refs(&self) -> Weak<()>
Weak pointer that can be used for ref-counting this execution plan and its streams.
Use Weak::strong_count to determine if the plan itself and its streams are dropped (should be 0 in that
case). Note that tokio might take some time to cancel spawned tasks, so you need to wrap this check into a retry
loop. Use assert_strong_count_converges_to_zero to archive this.