pub struct PanicExec { /* private fields */ }Expand description
Execution plan that emits streams that panics.
This is useful to test panic handling of certain execution plans.
Implementations
Sourceimpl PanicExec
impl PanicExec
Sourcepub fn new(schema: SchemaRef, n_partitions: usize) -> Self
pub fn new(schema: SchemaRef, n_partitions: usize) -> Self
Create new PanicExec with a give schema and number of
partitions, which will each panic immediately.
Sourcepub fn with_partition_panic(self, partition: usize, count: usize) -> Self
pub fn with_partition_panic(self, partition: usize, count: usize) -> Self
Set the number of batches prior to panic for a partition