pub struct WorkTableExec { /* private fields */ }Expand description
A temporary “working table” operation where the input data will be taken from the named handle during the execution and will be re-published as is (kind of like a mirror).
Most notably used in the implementation of recursive queries where the underlying relation does not exist yet but the data will come as the previous term is evaluated. This table will be used such that the recursive plan will register a receiver in the task context and this plan will use that receiver to get the data and stream it back up so that the batches are available in the next iteration.
Implementations