pub struct BufferExec { /* private fields */ }Expand description
WARNING: EXPERIMENTAL
Decouples production and consumption of record batches with an internal queue per partition, eagerly filling up the capacity of the queues even before any message is requested.
┌───────────────────────────┐
│ BufferExec │
│ │
│┌────── Partition 0 ──────┐│
││ ┌────┐ ┌────┐││ ┌────┐
──background poll────────▶│ │ │ ├┼┼───────▶ │
││ └────┘ └────┘││ └────┘
│└─────────────────────────┘│
│┌────── Partition 1 ──────┐│
││ ┌────┐ ┌────┐ ┌────┐││ ┌────┐
──background poll─▶│ │ │ │ │ ├┼┼───────▶ │
││ └────┘ └────┘ └────┘││ └────┘
│└─────────────────────────┘│
│ │
│ ... │
│ │
│┌────── Partition N ──────┐│
││ ┌────┐││ ┌────┐
──background poll───────────────▶│ ├┼┼───────▶ │
││ └────┘││ └────┘
│└─────────────────────────┘│
└───────────────────────────┘The capacity is provided in bytes, and for each buffered record batch it will take into account the size reported by RecordBatch::get_array_memory_size.
If a single record batch exceeds the maximum capacity set in the capacity argument, it’s still
allowed to pass in order to not deadlock the buffer.
This is useful for operators that conditionally start polling one of their children only after other child has finished, allowing to perform some early work and accumulating batches in memory so that they can be served immediately when requested.
Implementations
Sourceimpl BufferExec
impl BufferExec
Sourcepub fn new(input: Arc<dyn ExecutionPlan>, capacity: usize) -> Self
pub fn new(input: Arc<dyn ExecutionPlan>, capacity: usize) -> Self
Builds a new BufferExec with the provided capacity in bytes.
Sourcepub fn input(&self) -> &Arc<dyn ExecutionPlan>
pub fn input(&self) -> &Arc<dyn ExecutionPlan>
Returns the input ExecutionPlan of this BufferExec.
Sourcepub fn capacity(&self) -> usize
pub fn capacity(&self) -> usize
Returns the per-partition capacity in bytes for this BufferExec.