pub trait AsPhysicalExprRef {
// Required method
fn as_physical_expr_ref(&self) -> &Arc<dyn PhysicalExpr> ⓘ;
}Expand description
Allows a type to be treated as a reference to an
Arc<dyn PhysicalExpr>.
Used by apply_expression_roots.
Required Methods
Sourcefn as_physical_expr_ref(&self) -> &Arc<dyn PhysicalExpr> ⓘ
fn as_physical_expr_ref(&self) -> &Arc<dyn PhysicalExpr> ⓘ
Returns the referenced physical expression.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl AsPhysicalExprRef for Arc<dyn PhysicalExpr>
Allows an Arc<dyn PhysicalExpr> to be treated as a reference to itself.
impl AsPhysicalExprRef for Arc<dyn PhysicalExpr>
Allows an Arc<dyn PhysicalExpr> to be treated as a reference to itself.
This is needed because Arc<dyn PhysicalExpr> does not implement
AsRef<Arc<dyn PhysicalExpr>>.
fn as_physical_expr_ref(&self) -> &Arc<dyn PhysicalExpr> ⓘ
Sourceimpl<T> AsPhysicalExprRef for &Twhere
T: AsPhysicalExprRef + ?Sized,
impl<T> AsPhysicalExprRef for &Twhere
T: AsPhysicalExprRef + ?Sized,
fn as_physical_expr_ref(&self) -> &Arc<dyn PhysicalExpr> ⓘ
Implementors
impl AsPhysicalExprRef for ProjectionExpr
Allows a ProjectionExpr to be treated as a reference to its
Arc<dyn PhysicalExpr>.