pub struct ExtendedStatistics { /* private fields */ }Expand description
Statistics with support for custom extensions.
Wraps the standard Statistics and adds a type-erased extension map
for custom statistics like histograms, sketches, or domain-specific metadata.
Example
ⓘ
// Define a custom statistics extension
#[derive(Debug, Clone)]
struct HistogramStats {
buckets: Vec<(i64, i64, usize)>, // (min, max, count)
}
// Set extension in a planner
let mut stats = ExtendedStatistics::from(base_stats);
stats.set_extension(HistogramStats { buckets: vec![] });
// Retrieve in a consumer
if let Some(hist) = stats.get_extension::<HistogramStats>() {
// Use histogram for better estimation
}Implementations
Sourceimpl ExtendedStatistics
impl ExtendedStatistics
Sourcepub fn new(base: Statistics) -> Self
pub fn new(base: Statistics) -> Self
Create new ExtendedStatistics wrapping owned statistics.
Sourcepub fn new_arc(base: Arc<Statistics>) -> Self
pub fn new_arc(base: Arc<Statistics>) -> Self
Create new ExtendedStatistics from an Arc<Statistics>.
Sourcepub fn base(&self) -> &Statistics
pub fn base(&self) -> &Statistics
Returns a reference to the base Statistics.
Sourcepub fn base_arc(&self) -> &Arc<Statistics> ⓘ
pub fn base_arc(&self) -> &Arc<Statistics> ⓘ
Returns a reference to the underlying Arc<Statistics>.
Sourcepub fn get_extension<T: 'static + Send + Sync>(&self) -> Option<&T>
pub fn get_extension<T: 'static + Send + Sync>(&self) -> Option<&T>
Get a reference to a custom statistics extension by type.
Sourcepub fn set_extension<T: 'static + Send + Sync>(&mut self, value: T)
pub fn set_extension<T: 'static + Send + Sync>(&mut self, value: T)
Set a custom statistics extension.
Sourcepub fn has_extension<T: 'static + Send + Sync>(&self) -> bool
pub fn has_extension<T: 'static + Send + Sync>(&self) -> bool
Check if an extension of the given type exists.
Sourcepub fn merge_extensions(&mut self, other: &ExtendedStatistics)
pub fn merge_extensions(&mut self, other: &ExtendedStatistics)
Merge extensions from another ExtendedStatistics (other’s extensions take precedence).