pub struct PartialSortExec { /* private fields */ }Expand description
Sort execution plan for inputs that are already partially sorted.
This operator takes input ordered by a prefix of the required ordering, and
produces output ordered by the required ordering, emitting rows sooner
(streaming) and using less peak memory than SortExec which must buffer
all rows before producing any output.
PartialSortExec relies on the property that rows with the same sort
prefix are contiguous, so it can sort one prefix group at a time, emitting
completed groups without reading (and buffering) the entire input.
For example, if the required output is (a, b, c), but the input is only
ordered by (a, b), PartialSortExec sorts only within each (a, b)
group to produce output ordered by (a, b, c).
input ordered by a, b output ordered by a, b, c
+---+---+---+ +---+---+---+
| a | b | c | | a | b | c |
+---+---+---+ +---+---+---+
| 0 | 0 | 3 | -- new group --> | 0 | 0 | 1 |
| 0 | 0 | 2 | | 0 | 0 | 2 |
| 0 | 0 | 1 | | 0 | 0 | 3 |
| 0 | 1 | 1 | -- new group --> | 0 | 1 | 1 |
| 0 | 2 | 4 | -- new group --> | 0 | 2 | 0 |
| 0 | 2 | 0 | | 0 | 2 | 4 |
| 1 | 0 | 5 | -- new group --> | 1 | 0 | 5 |
+---+---+---+ +---+---+---+Buffering and Emitting Rows
PartialSortExec buffers rows only until it can prove a prefix group
will never be seen again, then sorts and emits buffered rows. A group is
guaranteed to never be seen again once a row with a different prefix
value arrives. This relies on the input’s existing ordering guarantees.
Using the example from above, rows accumulate in the in-memory buffer in
batches. As long as the (a, b) prefix keeps repeating, more rows are
buffered.
Buffer
+---+---+---+
| a | b | c |
+---+---+---+
| 0 | 0 | 3 |
| 0 | 0 | 2 |
| 0 | 0 | 1 |
+---+---+---+Once a batch arrives that contains a new (a, b) prefix, e.g. (0, 2):
every buffered row for previous prefixes may be emitted:
Buffer
+---+---+---+
| a | b | c |
+---+---+---+
| 0 | 0 | 3 |
| 0 | 0 | 2 |
| 0 | 0 | 1 |
| 0 | 1 | 1 | <-- first row of new batch, new prefix
| 0 | 2 | 4 | <-- new prefix
| 0 | 2 | 0 |
| 1 | 0 | 5 | <-- last row of new batch, new prefix
+---+---+---+Once known complete, the buffered rows are sorted by the full (a, b, c)
ordering and emitted as a RecordBatch; Any rows from the most recently
seen prefix remain buffered (as more rows with the same prefix may arrive in
future batches.
Emitted <-- fully sorted on (a, b, c)
+---+---+---+
| a | b | c |
+---+---+---+
| 0 | 0 | 1 | <-- completed group
| 0 | 0 | 2 |
| 0 | 0 | 3 |
| 0 | 2 | 0 | <-- completed group
| 0 | 2 | 4 |
| 0 | 1 | 1 | <-- completed group
+---+---+---+
Buffer
+---+---+---+
| a | b | c |
+---+---+---+
| 1 | 0 | 5 | <-- (possibly) in progress group
+---+---+---+Implementations
Sourceimpl PartialSortExec
impl PartialSortExec
Sourcepub fn new(
expr: LexOrdering,
input: Arc<dyn ExecutionPlan>,
common_prefix_length: usize,
) -> Self
pub fn new( expr: LexOrdering, input: Arc<dyn ExecutionPlan>, common_prefix_length: usize, ) -> Self
Create a new partial sort execution plan
Sourcepub fn preserve_partitioning(&self) -> bool
pub fn preserve_partitioning(&self) -> bool
Whether this PartialSortExec preserves partitioning of the children
Sourcepub fn with_preserve_partitioning(self, preserve_partitioning: bool) -> Self
pub fn with_preserve_partitioning(self, preserve_partitioning: bool) -> Self
Specify the partitioning behavior of this partial sort exec
If preserve_partitioning is true, sorts each partition
individually, producing one sorted stream for each input partition.
If preserve_partitioning is false, sorts and merges all
input partitions producing a single, sorted partition.
Sourcepub fn with_fetch(self, fetch: Option<usize>) -> Self
pub fn with_fetch(self, fetch: Option<usize>) -> Self
Modify how many rows to include in the result
If None, then all rows will be returned, in sorted order.
If Some, then only the top fetch rows will be returned.
This can reduce the memory pressure required by the sort
operation since rows that are not going to be included
can be dropped.
Sourcepub fn input(&self) -> &Arc<dyn ExecutionPlan> ⓘ
pub fn input(&self) -> &Arc<dyn ExecutionPlan> ⓘ
Input schema
Sourcepub fn expr(&self) -> &LexOrdering
pub fn expr(&self) -> &LexOrdering
Sort expressions
Sourcepub fn fetch(&self) -> Option<usize>
pub fn fetch(&self) -> Option<usize>
If Some(fetch), limits output to only the first “fetch” items
Sourcepub fn common_prefix_length(&self) -> usize
pub fn common_prefix_length(&self) -> usize
Common prefix length