pub struct SortExec { /* private fields */ }Expand description
Sort execution plan.
Support sorting datasets that are larger than the memory allotted by the memory manager, by spilling to disk.
Implementations
Sourceimpl SortExec
impl SortExec
Sourcepub fn new(expr: LexOrdering, input: Arc<dyn ExecutionPlan>) -> Self
pub fn new(expr: LexOrdering, input: Arc<dyn ExecutionPlan>) -> Self
Create a new sort execution plan that produces a single, sorted output partition.
Sourcepub fn preserve_partitioning(&self) -> bool
pub fn preserve_partitioning(&self) -> bool
Whether this SortExec preserves partitioning of the children
Sourcepub fn with_preserve_partitioning(self, preserve_partitioning: bool) -> Self
pub fn with_preserve_partitioning(self, preserve_partitioning: bool) -> Self
Specify the partitioning behavior of this sort exec
If preserve_partitioning is true, sorts each partition
individually, producing one sorted stream for each input partition.
If preserve_partitioning is false, sorts and merges all
input partitions producing a single, sorted partition.
Sourcepub fn with_fetch(&self, fetch: Option<usize>) -> Self
pub fn with_fetch(&self, fetch: Option<usize>) -> Self
Modify how many rows to include in the result
If None, then all rows will be returned, in sorted order.
If Some, then only the top fetch rows will be returned.
This can reduce the memory pressure required by the sort
operation since rows that are not going to be included
can be dropped.
Sourcepub fn input(&self) -> &Arc<dyn ExecutionPlan> ⓘ
pub fn input(&self) -> &Arc<dyn ExecutionPlan> ⓘ
Input schema
Sourcepub fn expr(&self) -> &LexOrdering
pub fn expr(&self) -> &LexOrdering
Sort expressions
Sourcepub fn fetch(&self) -> Option<usize>
pub fn fetch(&self) -> Option<usize>
If Some(fetch), limits output to only the first “fetch” items
Sourcepub fn dynamic_filter_expr(&self) -> Option<Arc<DynamicFilterPhysicalExpr>>
pub fn dynamic_filter_expr(&self) -> Option<Arc<DynamicFilterPhysicalExpr>>
Returns the dynamic filter expression for this sort (TopK), if set.
Sourcepub fn with_dynamic_filter_expr(
self,
filter: Arc<DynamicFilterPhysicalExpr>,
) -> Result<Self>
pub fn with_dynamic_filter_expr( self, filter: Arc<DynamicFilterPhysicalExpr>, ) -> Result<Self>
Replace the dynamic filter expression for this sort.
Resets any internal state which may depend on the previous dynamic filter.
Validates that the filter’s children reference valid columns in the sort’s input schema.