pub struct StreamingTableExec { /* private fields */ }Expand description
An ExecutionPlan for one or more PartitionStreams.
If your source can be represented as one or more PartitionStreams, you can
use this struct to implement ExecutionPlan.
Implementations
Sourceimpl StreamingTableExec
impl StreamingTableExec
Sourcepub fn try_new(
schema: SchemaRef,
partitions: Vec<Arc<dyn PartitionStream>>,
projection: Option<&Vec<usize>>,
projected_output_ordering: impl IntoIterator<Item = LexOrdering>,
infinite: bool,
limit: Option<usize>,
) -> Result<Self>
pub fn try_new( schema: SchemaRef, partitions: Vec<Arc<dyn PartitionStream>>, projection: Option<&Vec<usize>>, projected_output_ordering: impl IntoIterator<Item = LexOrdering>, infinite: bool, limit: Option<usize>, ) -> Result<Self>
Try to create a new StreamingTableExec returning an error if the schema is incorrect
Sourcepub fn with_output_partitioning(
self,
output_partitioning: Partitioning,
) -> Result<Self>
pub fn with_output_partitioning( self, output_partitioning: Partitioning, ) -> Result<Self>
Declares the output partitioning of this stream.
output_partitioning must describe this plan’s current output and have
the same number of partitions as the stream.
pub fn partitions(&self) -> &Vec<Arc<dyn PartitionStream>>
pub fn partition_schema(&self) -> &SchemaRef
pub fn projection(&self) -> &Option<Arc<[usize]>>
pub fn projected_schema(&self) -> &Schema
pub fn projected_output_ordering(&self) -> impl IntoIterator<Item = LexOrdering>
pub fn is_infinite(&self) -> bool
pub fn limit(&self) -> Option<usize>