pub struct MockExec { /* private fields */ }Expand description
A Mock ExecutionPlan that can be used for writing tests of other ExecutionPlans
Implementations
Sourceimpl MockExec
impl MockExec
Sourcepub fn new(data: Vec<Result<RecordBatch>>, schema: SchemaRef) -> Self
pub fn new(data: Vec<Result<RecordBatch>>, schema: SchemaRef) -> Self
Create a new MockExec with a single partition that returns
the specified Resultss.
By default, the batches are not produced immediately (the
caller has to actually yield and another task must run) to
ensure any poll loops are correct. This behavior can be
changed with with_use_task
Sourcepub fn with_use_task(self, use_task: bool) -> Self
pub fn with_use_task(self, use_task: bool) -> Self
If use_task is true (the default) then the batches are sent
back using a separate task to ensure the underlying stream is
not immediately ready
Sourcepub fn with_unknown_statistics(self) -> Self
pub fn with_unknown_statistics(self) -> Self
Report unknown statistics rather than computing them from data.
By default statistics are derived from data, which propagates any
planted errors when statistics are requested during planning (for
example when a parent node computes its properties). Use this when a
planted error should only surface at execution time.